from threading import Thread
from typing import Any
import zmq
import logging

from otmcm_backend.common.interfaces.zmq_channel import (
    ZMQReqRepServer
)

from otmcm_backend.common.models.channel_models import (
    DistributorMangerDistributorRequestChannelConfig,
    DistributorMangerUserScriptRequestChannelConfig
)
from otmcm_backend.common.models.mixsin_models import (
    MixsinLogger
)


class ServerDistributorManagerDistributorRequestChannel(DistributorMangerDistributorRequestChannelConfig, ZMQReqRepServer, MixsinLogger):

    CHANNEL_SOCKET_PATTERN = zmq.REP

    def run_worker(self):
        print("here 1")
        self.logger.info(f"DistributorManager's channel {self.__class__.__name__} is up and running at {self.channel_address}")
        while True:
            raw_msg = self.socket.recv_json()
            self.logger.debug(raw_msg)


class ServerDistributorMangerUserScriptRequestChannel(DistributorMangerUserScriptRequestChannelConfig, ZMQReqRepServer, MixsinLogger):

    CHANNEL_SOCKET_PATTERN = zmq.REP

    def run_worker(self):
        print("here 2")
        self.logger.info(f"DistributorManager's channel {self.__class__.__name__} is up and running at {self.channel_address}")
        while True:
            raw_msg = self.socket.recv_json()
            self.logger.debug(raw_msg)


class DistributorRequestChannel(ZMQReqRepServer):
    pass



import os
import yaml

from typing import Dict



def load_yaml_file(path_to_yaml_file:str) -> Dict:
    """Load and return the content of a yaml file as a dictionary

    Args:
        path_to_yaml_file ([str]): Path to the yaml file

    Returns:
        [Dict]: A dictionary representing the yaml file
    """
    with open(path_to_yaml_file, "r") as yaml_file:
        yaml_file_content_dict = yaml.safe_load(yaml_file)

    return yaml_file_content_dict


def get_path_to_file_in_same_folder(script__file__:str, neighbor_file_name:str) -> str:
    """Return the absoluate path to the file named neighbor_file_name in the same folder with the script whose
    absoluate file path is in script__file__

    Args:
        script__file__ (str): the __file__ of the script
        neighbor_file_name (str): The name of the neighbor file in the folder

    Returns:
        str: Absoluate path to the neighbot_file_name
    """
    # Get current folder of the script
    current_folder = os.path.abspath(os.path.dirname(__file__))
    # Join the folder with the neighbor file name to get absoluate path
    return os.path.join(current_folder, neighbor_file_name)


import setuptools
import json

# def next_version()->str:
#     config_key = "package_version"
#     with open("version.json", "r", encoding="utf-8") as fh:
#         version_config = json.loads(fh.read())
#     split_version = version_config.get(config_key).split(".")
#     # Increase minor version
#     split_version[-1] = str(int(split_version[-1]) + 1)
#     version_config[config_key] =  ".".join(split_version)
#     with open("version.json", "w", encoding="utf-8") as fh:
#         fh.write(json.dumps(version_config, indent=4))
#     return version_config.get(config_key)

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="otmcm-backend",
    version="0.0.22",
    author="Huan Tran",
    author_email="huankimtran@gmail.com",
    description="Backend package for otmcm algotrading environment",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/huankimtran/OTMCM",
    project_urls={
        "Bug Tracker": "https://github.com/huankimtran/OTMCM",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.8",
    install_requires=[
        "pyzmq >= 18.1.1"
    ],
    scripts=[
        "bin/otmcm_launch.py"
    ]
)